/* $Header: /fridge/cvs/xscorch/sgame/shelp.h,v 1.3 2009-04-26 17:39:40 jacob Exp $ */
/*
  
   xscorch - shelp.h          Copyright(c) 2001 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/

   Scorched simple help system


   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, version 2 of the License ONLY.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

*/
#ifndef __shelp_h_included
#define __shelp_h_included


#include <xscorch.h>


void sc_help_text(char *res, int size, const char *idphrase);


#endif /* __shelp_h_included */

